ethexe-node-wrapper 2.0.0-pre.1

Node process wrapper utilities for ethexe
docs.rs failed to build ethexe-node-wrapper-2.0.0-pre.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.

Vara.eth node wrapper.

Node wrapper is a wrapper around the Vara.eth node. Internally, it do the next things:

  • spawns the Vara.eth node process
    • spawns the Anvil node process
    • deploy Ethereum smart-contracts on Anvil
  • provides the access to node PRC endpoints and Ethereum RPC endpoint

Modules

  • [node] - provides the [VaraEth] struct - the node configurator
  • [instance] - provides the [VaraEthInstance] struct - the instance which holds the inner spawned process and RPC endpoints.
  • [error] - provides the [Error] enum - the error type for module errors.